@@ -45,8 +45,11 @@ overwrite = FALSE,
 intermediate = TRUE,
 inSweave = FALSE,
 fromRForge = TRUE,
-base.url = paste("http://r-forge.r-project.org/plugins/scmsvn/viewcvs.php/",
-                            "*checkout*/pkg/", sep = ""),
+#base.url = paste("http://r-forge.r-project.org/plugins/scmsvn/viewcvs.php/",
+#                            "*checkout*/pkg/", sep = ""),
+base.url = paste("http://r-forge.r-project.org/scm/viewvc.php/",
+                            "*checkout*/pkg/", 
+                            sep = ""),
 addRset = TRUE,
 addRdset = TRUE,
 addRinset = TRUE,
